DeeResponsiveColumn class

Constructors

DeeResponsiveColumn({required Widget child, int sm = 6, int md = 8, int lg = 10, int xl = 12, Alignment alignment = Alignment.topLeft})

Properties

alignment Alignment
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
lg int
final
md int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm int
final
xl int
final

Methods

getColSpan(double width) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited