DeeResponsiveColumn constructor
DeeResponsiveColumn({})
Creates a DeeResponsiveColumn with specified child, column spans and alignment.
sm is the number of columns to span on small screens (default is 6).
md is the number of columns to span on medium screens (default is 8).
lg is the number of columns to span on large screens (default is 10).
xl is the number of columns to span on extra-large screens (default is 12).
alignment is the alignment of the widget within the column (default is Alignment.topLeft).
child is the widget to be displayed inside the column.
Implementation
DeeResponsiveColumn({
required this.child,
this.sm = 6,
this.md = 8,
this.lg = 10,
this.xl = 12,
this.alignment = Alignment.topLeft,
});