DeeResponsiveColumn class
A class representing a responsive column configuration.
Constructors
Properties
- alignment → Alignment
-
The alignment of the column.
final
- child → Widget
-
The child widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lg → int
-
The number of columns to span on large screens.
final
- md → int
-
The number of columns to span on medium screens.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sm → int
-
The number of columns to span on small screens.
final
- xl → int
-
The number of columns to span on extra large screens.
final
Methods
-
getColSpan(
double width) → int - Gets the number of columns to span based on the screen width.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited